pycocoa.utils.Adict

Package pycocoa :: Module utils :: Class Adict |
[frames] | no frames]

# Class Adict

    object --+
             |
          dict --+
                 |
                Adict

A `dict` with key and attribute access to the items and callable to add items.

Instance Methods
__call__(self, **kwds) Equivalent to `self.update(kwds)`. |
__getattr__(self, name) Get the value of an attribute or item by `name`. |
__str__(self) Return this `Adict` as `str`. |
a shallow copy of D |
copy(self) Return a shallow copy. |
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setitem__`, `__sizeof__`, `clear`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
Inherited from `object`: `__class__`

Method Details

### __str__(self) (Informal representation operator) |
Return this `Adict` as `str`. Overrides: object.__str__

### copy(self) |
Return a shallow copy. Returns: a shallow copy of D Overrides: dict.copy